@@ -1,9 +1,12 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+from __future__ import absolute_import
 import os
 import subprocess
 
+#import pdb
+
 # get a dynamic version number, if possible.  if not running from git
 # should default to static version
 cwd = os.getcwd()
@@ -28,7 +31,7 @@ try:
         __version__ = "git {}".format(stdout.strip())
     os.chdir(cwd)
 
-except IOError:
-    __version__ = "2.0.3"
+except:
+    __version__ = "2.0.6"
     if not os.getcwd == cwd:
         os.chdir(cwd)
